/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Certus SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

import java.util.Arrays;

/*  Serial Port Pass-through */
public class ANPacket10
{
	public static final int PASS_THROUGH_DATA_MAXIMUM_LENGTH = 254;

	public static final int PRIMARY						= 0;
	public static final int GPIO_1_AND_2				= 1;
	public static final int AUXILIARY_RS232				= 2;
	public static final int GPIO_EMULATION				= 3;
	public static final int AUXILIARY_EMULATION 		= 4;
	public static final int GNSS_RECEIVER_1				= 5;
	public static final int GNSS_RECEIVER_2				= 6;
	public static final int PASS_THROUGH_ROUTE_MAXIMUM 	= 6;

	public int passThroughRoute;
	public byte[] passThroughData;

	public ANPacket10(int route, byte[] data)
	{
		passThroughRoute = route;
		passThroughData = data;
	}

	public ANPacket10(ANPacket packet)
	{
		if (packet != null && packet.length >= 1)
		{
			passThroughRoute = packet.data[0] & 0xFF;
			passThroughData = Arrays.copyOfRange(packet.data, 1, packet.length);
		}
		else
		{
			passThroughRoute = -1;
			passThroughData = new byte[0];
		}
	}

	public ANPacket toANPacket() throws IndexOutOfBoundsException
	{
		if (passThroughRoute < 0 || passThroughRoute > PASS_THROUGH_ROUTE_MAXIMUM)
		{
			throw new IndexOutOfBoundsException();
		}
		if (passThroughData.length < 0 || passThroughData.length > PASS_THROUGH_DATA_MAXIMUM_LENGTH)
		{
			throw new IndexOutOfBoundsException();
		}
		ANPacket packet = new ANPacket(passThroughData.length + 1, ANPacket.PACKET_ID_PASS_THROUGH);
		packet.data[0] = (byte) (passThroughRoute & 0xFF);
		for (int i = 0; i < passThroughData.length; i++)
		{
			packet.data[1 + i] = passThroughData[i];
		}
		return packet;
	}
}
