/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Certus SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* Extended Device Information */
public class ANPacket13 extends ANPacket3
{
	public static final int LENGTH = 36;

	public static final int DEVICE_SUBTYPE_ID_UNKNOWN = 255;
	public static final int DEVICE_SUBTYPE_ID_CERTUS = 0;
	public static final int DEVICE_SUBTYPE_ID_CERTUS_EVO = 1;
	public static final int DEVICE_SUBTYPE_ID_CERTUS_OEM = 2;
	public static final int DEVICE_SUBTYPE_ID_CERTUS_EVO_OEM = 3;

	public long deviceSubType;

	public ANPacket13()
	{
		softwareVersion = 0;
		deviceID = 0;
		hardwareRevision = 0;
		serialNumber = new long[3];
		serialNumber[0] = 0;
		serialNumber[1] = 0;
		serialNumber[2] = 0;
		deviceSubType = DEVICE_SUBTYPE_ID_UNKNOWN;
	}

	public ANPacket13(ANPacket packet)
	{
		softwareVersion = TypeConversion.bytesToUInt32(packet.data, 0);
		deviceID = TypeConversion.bytesToUInt32(packet.data, 4);
		hardwareRevision = TypeConversion.bytesToUInt32(packet.data, 8);
		serialNumber = new long[3];
		serialNumber[0] = TypeConversion.bytesToUInt32(packet.data, 12);
		serialNumber[1] = TypeConversion.bytesToUInt32(packet.data, 16);
		serialNumber[2] = TypeConversion.bytesToUInt32(packet.data, 20);
		deviceSubType = TypeConversion.bytesToUInt32(packet.data, 24);
	}
	
	public String deviceIdString()
	{
		switch ((int)deviceID)
		{
			case DEVICE_ID_CERTUS:
				switch ((int) deviceSubType)
				{
					case DEVICE_SUBTYPE_ID_CERTUS:
						return "Certus";
					case DEVICE_SUBTYPE_ID_CERTUS_EVO:
						return "Certus Evo";
					case DEVICE_SUBTYPE_ID_CERTUS_OEM:
						return "Certus OEM";
					case DEVICE_SUBTYPE_ID_CERTUS_EVO_OEM:
						return "Certus Evo OEM";
					default:
						return super.deviceIdString();
				}
			default:
				return super.deviceIdString();
		}
	}
}
