/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Certus SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* Filter Options */
public class ANPacket186
{
	public static final int LENGTH = 17;

	public static final int VEHICLE_TYPE_UNCONSTRAINED = 0;
	public static final int VEHICLE_TYPE_BICYCLE_OR_MOTORCYCLE = 1;
	public static final int VEHICLE_TYPE_CAR = 2;
	public static final int VEHICLE_TYPE_HOVERCRAFT = 3;
	public static final int VEHICLE_TYPE_SUBMARINE = 4;
	public static final int VEHICLE_TYPE_3D_UNDERWATER_VEHICLE = 5;
	public static final int VEHICLE_TYPE_FIXED_WING_PLANE = 6;
	public static final int VEHICLE_TYPE_3D_AIRCRAFT = 7;
	public static final int VEHICLE_TYPE_HUMAN = 8;
	public static final int VEHICLE_TYPE_BOAT = 9;
	public static final int VEHICLE_TYPE_LARGE_SHIP = 10;
	public static final int VEHICLE_TYPE_STATIONARY = 11;
	public static final int VEHICLE_TYPE_STUNT_PLANE = 12;
	public static final int VEHICLE_TYPE_RACE_CAR = 13;
	public static final int VEHICLE_TYPE_MAXIMUM = 13;
	
	public Boolean permanent;
	public int vehicleType;
	public Boolean internalGNSSEnabled;
	public Boolean magnetometersEnabled;
	public Boolean atmosphericAltitudeEnabled;
	public Boolean velocityHeadingEnabled;
	public Boolean reversingDetectionEnabled;
	public Boolean motionAnalysisEnabled;
	public Boolean automaticMagneticCalibrationEnabled;

	public ANPacket186()
	{
	}

	public ANPacket186(ANPacket packet)
	{
		permanent = packet.data[0] != 0;
		vehicleType = packet.data[1] & 0xFF;
		internalGNSSEnabled = packet.data[2] != 0;
		magnetometersEnabled = packet.data[3] != 0;
		atmosphericAltitudeEnabled = packet.data[4] != 0;
		velocityHeadingEnabled = packet.data[5] != 0;
		reversingDetectionEnabled = packet.data[6] != 0;
		motionAnalysisEnabled = packet.data[7] != 0;
		automaticMagneticCalibrationEnabled = packet.data[8] != 0;
	}
	
	public ANPacket toANPacket() throws IndexOutOfBoundsException
	{	
		ANPacket packet = new ANPacket(17, ANPacket.PACKET_ID_FILTER_OPTIONS);
		packet.data[0] = (byte) (permanent ? 1 : 0);
		if (vehicleType < 0 || vehicleType > VEHICLE_TYPE_MAXIMUM) throw new IndexOutOfBoundsException();
		packet.data[1] = (byte) (vehicleType);
		packet.data[2] = (byte) (internalGNSSEnabled ? 1 : 0);
		packet.data[3] = (byte) (magnetometersEnabled ? 1 : 0);
		packet.data[4] = (byte) (atmosphericAltitudeEnabled ? 1 : 0);
		packet.data[5] = (byte) (velocityHeadingEnabled ? 1 : 0);
		packet.data[6] = (byte) (reversingDetectionEnabled ? 1 : 0);
		packet.data[7] = (byte) (motionAnalysisEnabled ? 1 : 0);
		packet.data[8] = (byte) (automaticMagneticCalibrationEnabled ? 1 : 0);
		for(int i = 9; i < 17; i++)
		{
			packet.data[i] = 0;
		}
		return packet;
	}
	
	public String vehicleTypeText()
	{
		switch(vehicleType)
		{
			case VEHICLE_TYPE_UNCONSTRAINED:
				return "Unlimited";
			case VEHICLE_TYPE_BICYCLE_OR_MOTORCYCLE:
				return "Bicycle";
			case VEHICLE_TYPE_CAR:
				return "Car";
			case VEHICLE_TYPE_HOVERCRAFT:
				return "Hovercraft";
			case VEHICLE_TYPE_SUBMARINE:
				return "Submarine";
			case VEHICLE_TYPE_3D_UNDERWATER_VEHICLE:
				return "3D Underwater Vehicle";
			case VEHICLE_TYPE_FIXED_WING_PLANE:
				return "Fixed Wing Plane";
			case VEHICLE_TYPE_3D_AIRCRAFT:
				return "3D Aircraft";
			case VEHICLE_TYPE_HUMAN:
				return "Human";
			case VEHICLE_TYPE_BOAT:
				return "Boat";
			case VEHICLE_TYPE_LARGE_SHIP:
				return "Large Ship";
			case VEHICLE_TYPE_STATIONARY:
				return "Stationary";
			case VEHICLE_TYPE_STUNT_PLANE:
				return "Stunt Plane";
			case VEHICLE_TYPE_RACE_CAR:
				return "Race Car";
			default:
				return "Unknown";
		}
	}
}
